@@ -380,6 +380,8 @@ def add_new_record(_add_value, _class, func=None):
     if func is not None:
         _add_value.module = func.__module__
         _add_value.func = func.__name__
+    if db_engine is None:
+        init()
     _add_value = add_common_columns(_add_value)
     return add(_add_value)
 
